@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,14 +31,14 @@ class MAILIMPORTER_EXPORT FilterImporterBase
 public:
     explicit FilterImporterBase(MailImporter::FilterInfo *info);
     virtual ~FilterImporterBase();
-    virtual bool importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MailImporter::MessageStatus &status);
-    virtual bool importMessage(const KArchiveFile *file, const QString &folderPath, int &nbTotal, int &fileDone);
+    Q_REQUIRED_RESULT virtual bool importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MailImporter::MessageStatus &status);
+    Q_REQUIRED_RESULT virtual bool importMessage(const KArchiveFile *file, const QString &folderPath, int &nbTotal, int &fileDone);
     virtual void clear();
     virtual void clearCountDuplicate();
-    virtual int countDuplicates() const;
-    virtual QString topLevelFolder() const;
+    Q_REQUIRED_RESULT virtual int countDuplicates() const;
+    Q_REQUIRED_RESULT virtual QString topLevelFolder() const;
 protected:
-    MailImporter::FilterInfo *mInfo;
+    MailImporter::FilterInfo *mInfo = nullptr;
 };
 }
 #endif // FILTERIMPORTERBASE_H
