@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,17 +19,18 @@
 #ifndef MAILIMPORTER_UTILS_H
 #define MAILIMPORTER_UTILS_H
 
-namespace MailImporter
-{
+namespace MailImporter {
 /**
  * Glorified QString[N] for (a) understandability (b) older gcc compatibility.
  */
-template <unsigned int size> class FolderStructureBase
+template<unsigned int size> class FolderStructureBase
 {
 public:
     typedef QString NString[size];
     /** Constructor. Need a default constructor for QValueList. */
-    FolderStructureBase() {}
+    FolderStructureBase()
+    {
+    }
 
     /** Constructor. Turn N QStrings into a folder structure
      *   description.
@@ -81,10 +83,10 @@ public:
             return d[0];
         }
     }
+
 private:
     QString d[size];
 };
 }
 
 #endif /* MAILIMPORTER_UTILS_H */
-
